@@ -31,12 +31,12 @@ from servo.assembly import (
     _default_routes,
 )
 from servo.connector import (
-    BaseConnector, 
+    BaseConnector,
     Optimizer,
     _connector_class_from_string
 )
 from servo.events import EventHandler, EventResult, Preposition
-from servo.logging import logger, set_level as set_log_level
+import servo.logging
 from servo.servo import (
     Events,
     Servo,
@@ -89,6 +89,7 @@ class Context(typer.Context):
     token: Optional[str] = None
     token_file: Optional[Path] = None
     base_url: Optional[str] = None
+    url: Optional[str] = None
 
     # Assembled servo
     assembly: Optional[Assembly] = None
@@ -113,6 +114,7 @@ class Context(typer.Context):
             "token",
             "token_file",
             "base_url",
+            "url"
         }
 
     def __init__(
@@ -128,6 +130,7 @@ class Context(typer.Context):
         token: Optional[str] = None,
         token_file: Optional[Path] = None,
         base_url: Optional[str] = None,
+        url: Optional[str] = None,
         **kwargs,
     ):
         self.config_file = config_file
@@ -354,6 +357,13 @@ class CLI(typer.Typer):
             metavar="URL",
             help="Base URL for connecting to Opsani API",
         ),
+        url: str = typer.Option(
+            None,
+            hidden=True,
+            envvar="OPSANI_URL",
+            metavar="URL",
+            help="Complete URL to reach the Opsani API, overriding the URL computed from the base URL"
+        ),
         config_file: Path = typer.Option(
             "servo.yaml",
             "--config-file",
@@ -375,14 +385,22 @@ class CLI(typer.Typer):
             envvar="SERVO_LOG_LEVEL",
             show_envvar=True,
             help="Set the log level",
-        )        
+        ),
+        no_color: Optional[bool] = typer.Option(
+            None,
+            "--no-color",
+            envvar=["SERVO_NO_COLOR", "NO_COLOR"],
+            help="Disable colored output"
+        )
     ):
         ctx.config_file = config_file
         ctx.optimizer = optimizer
         ctx.token = token
         ctx.token_file = token_file
         ctx.base_url = base_url
-        set_log_level(log_level)
+        ctx.url = url
+        servo.logging.set_level(log_level)
+        servo.logging.set_colors(not no_color)
 
         # TODO: This should be pluggable
         if ctx.invoked_subcommand not in {
@@ -399,16 +417,16 @@ class CLI(typer.Typer):
                 raise typer.Exit(2)
 
     @staticmethod
-    def assemble_from_context(ctx: Context):        
+    def assemble_from_context(ctx: Context):
         if ctx.config_file is None:
             raise typer.BadParameter("Config file must be specified")
-        
+
         if not ctx.config_file.exists():
             raise typer.BadParameter(f"Config file '{ctx.config_file}' does not exist")
 
         if ctx.optimizer is None:
             raise typer.BadParameter("An optimizer must be specified")
-        
+
         # Resolve token
         if ctx.token is None and ctx.token_file is None:
             raise typer.BadParameter(
@@ -424,7 +442,7 @@ class CLI(typer.Typer):
         if len(ctx.token) == 0 or ctx.token.isspace():
             raise typer.BadParameter("token cannot be blank")
 
-        optimizer = Optimizer(ctx.optimizer, token=ctx.token, base_url=ctx.base_url)
+        optimizer = Optimizer(ctx.optimizer, token=ctx.token, base_url=ctx.base_url, url=ctx.url)
 
         # Assemble the Servo
         try:
@@ -466,7 +484,7 @@ class CLI(typer.Typer):
                 return connectors
         else:
             return None
-    
+
     @staticmethod
     def connectors_type_callback(
         context: typer.Context, value: Optional[Union[str, List[str]]]
@@ -523,7 +541,7 @@ class CLI(typer.Typer):
                 raise typer.BadParameter(f"no connector found for identifier '{identifier}'")
 
         return routes
-    
+
     @staticmethod
     def duration_callback(
         context: typer.Context, value: Optional[str]
@@ -535,7 +553,7 @@ class CLI(typer.Typer):
         """
         if not value:
             return None
-        
+
         try:
             return Duration(value)
         except ValueError as e:
@@ -922,7 +940,7 @@ class ServoCLI(CLI):
                 c_list = connectors_by_type.get(c_type, [])
                 c_list.append(c)
                 connectors_by_type[c_type] = c_list
-            
+
             for connector_type in connectors_by_type.keys():
                 if all:
                     names = [connector_type.__default_name__]
@@ -940,7 +958,8 @@ class ServoCLI(CLI):
         def run(
             context: Context,
             check: bool = typer.Option(
-                False, "--check", "-c", help="Verify all checks pass before running"
+                False, "--check", "-c", help="Verify all checks pass before running",
+                envvar="SERVO_RUN_CHECK"
             )
         ) -> None:
             """
@@ -949,7 +968,7 @@ class ServoCLI(CLI):
             if check:
                 typer_click_object = typer.main.get_group(self)
                 context.invoke(
-                    typer_click_object.commands["check"], 
+                    typer_click_object.commands["check"],
                     exit_on_success=False
                 )
 
@@ -1009,28 +1028,28 @@ class ServoCLI(CLI):
                 validate_connectors_respond_to_event(connectors, Events.CHECK)
             else:
                 connectors = context.assembly.connectors
-            
+
             def parse_re(value: Optional[List[str]]) -> Union[None, List[str], Pattern[str]]:
                 if value and len(value) == 1:
                     val = value[0]
                     if val[:1] == '/' and val[-1] == '/':
                         return re.compile(val[1:-1])
-                
+
                 return value
-            
+
             def parse_csv(value: Optional[List[str]]) -> Union[None, List[str], Pattern[str]]:
                 if value and len(value) == 1:
                     val = value[0]
                     if "," in val:
                         return list(map(lambda v: v.strip(), val.split(",")))
-                
+
                 return value
-            
+
             def parse_id(value: Optional[List[str]]) -> Union[None, List[str], Pattern[str]]:
                 v = parse_re(value)
                 if not isinstance(v, Pattern):
                     return parse_csv(v)
-                
+
                 return v
 
             args = dict(name=parse_re(name), id=parse_id(id), tags=parse_csv(tag))
@@ -1040,10 +1059,12 @@ class ServoCLI(CLI):
                 Events.CHECK, filter_, include=connectors, halt_on=halt_on
             ))
 
+            import textwrap
+
             table = []
             ready = True
             if verbose:
-                headers = ["CONNECTOR", "CHECK", "ID", "TAGS", "STATUS", "MESSAGE"]                    
+                headers = ["CONNECTOR", "CHECK", "ID", "TAGS", "STATUS", "MESSAGE"]
                 for result in results:
                     checks: List[Check] = result.value
                     names, ids, tags, statuses, comments = [], [], [], [], []
@@ -1052,15 +1073,15 @@ class ServoCLI(CLI):
                         ids.append(check.id)
                         tags.append(", ".join(check.tags) if check.tags else "-")
                         statuses.append("√ PASSED" if check.success else "X FAILED")
-                        comments.append(check.message or "-")
+                        comments.append(textwrap.shorten(check.message or "-", 70))
                         ready &= check.success
-                    
+
                     if not names:
                         continue
 
                     row = [result.connector.name, "\n".join(names), "\n".join(ids), "\n".join(tags), "\n".join(statuses), "\n".join(comments)]
                     table.append(row)
-            else:                    
+            else:
                 headers = ["CONNECTOR", "STATUS", "ERRORS"]
                 for result in results:
                     checks: List[Check] = result.value
@@ -1071,13 +1092,13 @@ class ServoCLI(CLI):
                     errors = []
                     for check in checks:
                         success &= check.success
-                        check.success or errors.append(f"{check.name}: {check.message or '-'}")
+                        check.success or errors.append(f"{check.name}: {textwrap.wrap(check.message or '-')}")
                     ready &= success
                     status = "√ PASSED" if success else "X FAILED"
                     message = reduce(lambda m, e: m + f"({errors.index(e) + 1}/{len(errors)}) {e}\n", errors, "")
                     row = [result.connector.name, status, message]
                     table.append(row)
-                
+
             # Output table and exit
             if not quiet:
                 typer.echo(tabulate(table, headers, tablefmt="plain"))
@@ -1199,10 +1220,10 @@ class ServoCLI(CLI):
         ) -> None:
             """
             Capture measurements for one or more metrics
-            """            
+            """
             if not connectors:
                 connectors = list(filter(lambda c: c.responds_to_event(Events.MEASURE), context.assembly.connectors))
-            
+
             # TODO: Test combination of metrics + connector options
             if metrics:
                 # Filter target connectors by metrics
@@ -1214,14 +1235,14 @@ class ServoCLI(CLI):
                     metric_names: Set[str] = set(map(lambda m: m.name, result_metrics))
                     if not metric_names | set(metrics):
                         connectors.remove(result.connector)
-            
+
             # Capture the measurements
             results: List[EventResult] = sync(context.servo.dispatch_event(
                 Events.MEASURE, metrics=metrics, control=Control(duration=duration), include=connectors
             ))
 
             # FIXME: The data that is crossing connector boundaries needs to be validated
-            aggregated_by_metric: Dict[Metric, Dict[str, Dict[BaseConnector, List[Tuple[Numeric, Reading]]]]] = {}                       
+            aggregated_by_metric: Dict[Metric, Dict[str, Dict[BaseConnector, List[Tuple[Numeric, Reading]]]]] = {}
             metric_names = list(map(lambda m: m.name, metrics)) if metrics else None
             headers = ["METRIC", "UNIT", "READINGS"]
             table = []
@@ -1231,7 +1252,7 @@ class ServoCLI(CLI):
                     continue
                 for reading in measurement.readings: # List[TimeSeries]
                     metric = reading.metric
-                    
+
                     metric_to_timestamp = aggregated_by_metric.get(metric, {})
                     for value_tuple in reading.values: # List[Tuple[datetime, Numeric]]
                         time_key = f"{value_tuple[0]:%Y-%m-%d %H:%M:%S}"
@@ -1242,8 +1263,8 @@ class ServoCLI(CLI):
                         metric_to_timestamp[time_key] = timestamp_to_connector
 
                     aggregated_by_metric[metric] = metric_to_timestamp
-            
-            # Print the table            
+
+            # Print the table
             def attribute_connector(connector, reading) -> str:
                 return f"[{connector.name}{reading.id or ''}]" if len(connectors) > 1 else ""
 
@@ -1261,7 +1282,7 @@ class ServoCLI(CLI):
                 row = [
                     metric.name,
                     metric.unit,
-                    "\n".join(readings_column),                            
+                    "\n".join(readings_column),
                 ]
                 table.append(row)
             typer.echo(tabulate(table, headers, tablefmt="plain"))
@@ -1283,13 +1304,13 @@ class ServoCLI(CLI):
                 component_name, setting_descriptor = descriptor.split(".", 1)
                 setting_name, value = setting_descriptor.split("=", 1)
                 adjustment = Adjustment(
-                    component_name=component_name, 
+                    component_name=component_name,
                     setting_name=setting_name,
                     value=value
                 )
                 adjustments.append(adjustment)
 
-            
+
             results: List[EventResult] = sync(context.servo.dispatch_event(
                 Events.ADJUST, adjustments
             ))
@@ -1298,12 +1319,12 @@ class ServoCLI(CLI):
 
                 if isinstance(outcome, Exception):
                     message = str(outcome.get("message", "undefined"))
-                    raise ConnectorError(                        
+                    raise ConnectorError(
                         f'Adjustment connector failed with error "{outcome}" and message:\n{message}'
                     )
                 else:
                     self.logger.info(f"{result.connector.name} - Adjustment completed")
-                    
+
 
         @self.command(section=section, hidden=True)
         def promote() -> None:
@@ -1361,7 +1382,7 @@ class ServoCLI(CLI):
                                 "type": connector.full_name,
                                 "description": connector.description,
                                 "version": str(connector.version),
-                                "url": str(connector.homepage),                                
+                                "url": str(connector.homepage),
                             }
                         )
                     connectors_json_str = json.dumps(connectors, indent=None)
@@ -1588,7 +1609,7 @@ class ServoCLI(CLI):
                 else:
                     # If there are no aliases just assign input values
                     config.connectors = connectors
-            
+
             config_yaml = config.yaml(
                 by_alias=True, exclude_unset=exclude_unset, exclude_defaults=exclude_unset, exclude=exclude, exclude_none=True
             )
@@ -1669,7 +1690,7 @@ class ServoCLI(CLI):
                     raise typer.BadParameter(f"no connector found for key '{identifier}'")
             else:
                 connector_class = Servo
-            
+
             if short:
                 if format == VersionOutputFormat.text:
                     typer.echo(f"{connector_class.full_name} v{connector_class.version}")
@@ -1723,6 +1744,6 @@ def sync(future: Union[asyncio.Future, asyncio.Task, Awaitable]) -> Any:
         Any: The Future's result.
 
     Raises:
-        Exception: 
+        Exception:
     """
     return asyncio.get_event_loop().run_until_complete(future)
